# Putki

Pipeline (Finnish: putki) - discovering and executing a specific task description.

[License: MIT](https://git.sr.ht/~sthagen/putki/tree/default/item/LICENSE)

Third party dependencies are documented in the folder [third-party](third-party/README.md).

[![version](https://img.shields.io/pypi/v/putki.svg?style=flat)](https://pypi.python.org/pypi/putki/)
[![downloads](https://pepy.tech/badge/putki/month)](https://pepy.tech/project/putki)
[![wheel](https://img.shields.io/pypi/wheel/putki.svg?style=flat)](https://pypi.python.org/pypi/putki/)
[![supported-versions](https://img.shields.io/pypi/pyversions/putki.svg?style=flat)](https://pypi.python.org/pypi/putki/)
[![supported-implementations](https://img.shields.io/pypi/implementation/putki.svg?style=flat)](https://pypi.python.org/pypi/putki/)

## Documentation

User and developer [documentation of putki](https://codes.dilettant.life/docs/putki).

## Bug Tracker

Feature requests and bug reports are best entered in the [todos of putki](https://todo.sr.ht/~sthagen/putki).

## Primary Source repository

The main source of `putki` is on a mountain in central Switzerland.
We use distributed version control (git). No central hub. Each clone can become a new source for the benefit of all.
The preferred public clones of `putki` are:

* [on codeberg](https://codeberg.org/sthagen/putki) - a democratic community-driven, non-profit software development platform operated by Codeberg e.V.
* [at sourcehut](https://git.sr.ht/~sthagen/putki) - a collection of tools useful for software development.

# Status

Experimental.

**Note**: The default branch is `default`. 
